@@ -98,7 +98,7 @@ tie %Config, 'Config', {
     ldlibpthname => 'LD_LIBRARY_PATH',
     libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib',
     osname => 'linux',
-    osvers => '6.12.25-serv',
+    osvers => '6.12.48+deb13-amd64',
     path_sep => ':',
     privlibexp => '/usr/lib64/perl5/5.42',
     scriptdir => '/usr/bin',
